@@ -1,3 +1,6 @@
+from beanstalk.tasks.action.server import create_database
+
+
 def _(var):
     return var() if callable(var) else var
 
@@ -16,7 +19,9 @@ PRE_SETUP_ACTIONS = []  # Only beanstalk settings
 POST_SETUP_ACTIONS = []  # Only beanstalk settings
 
 PRE_CREATE_ACTIONS = []  # project_name
-POST_CREATE_ACTIONS = []  # project_name, uwsgi_port
+POST_CREATE_ACTIONS = [
+    create_database,
+]  # project_name, uwsgi_port
 
 PRE_COMMIT_ACTIONS = []  # project_name
 POST_COMMIT_ACTIONS = []  # project_name
