@@ -7,39 +7,41 @@ from beanstalk import (BEANSTALK_ROOT_PATH, BEANSTALK_GLOBAL_BASE_PATH,
 from beanstalk.titles import section_title
 
 
-def load_role_settings(role=None, local_settings_path=None, load_again=False, **setting_patches):
+def load_role_settings(role=None, local_settings_path=None, load_again=False, default_only=False, **setting_patches):
     """Load beanstalk settings in
     """
-    if not load_again and env.get('beanstalk_settings', None) is not None:
-        return env.beanstalk_settings
+    env_key = 'beanstalk_settings' if not default_only else 'beanstalk_default_settings'
+    if not load_again and env_key in env:
+        return env[env_key]
 
     # Check role
     if role is None:
         role = env.get('beanstalk_role', None)
     if role not in ('app', 'server'):
-        abort('I don\'t know this role. (%s)' % role)
+        abort('I don\'t know this role. ({role})'.format(role=role))
 
     # Get default settings path
     setting_paths = []
-    default_settings_path = os.path.join(BEANSTALK_ROOT_PATH, 'default_settings/default_%s_settings.py' % role)
+    default_settings_path = os.path.join(BEANSTALK_ROOT_PATH, 'default_settings/default_{0}_settings.py'.format(role))
     setting_paths.append(default_settings_path)
     # Get global role settings path
-    global_settings_path = os.path.join(BEANSTALK_GLOBAL_BASE_PATH, '%s_settings.py' % role)
+    global_settings_path = os.path.join(BEANSTALK_GLOBAL_BASE_PATH, '{0}_settings.py'.format(role))
     if os.path.exists(global_settings_path):
         setting_paths.append(global_settings_path)
     # Get local role settings path
-    if local_settings_path is None:
-        local_settings_path = env.get('beanstalk_%s_settings_path' % role, None)
-    if local_settings_path is None:
-        local_settings_path = os.path.join(
-            os.getcwd(), BEANSTALK_LOCAL_BASE_PATH, 'beanstalk_%s_settings.py' % role
-        )
-    if local_settings_path is not None and os.path.exists(local_settings_path):
-        setting_paths.append(local_settings_path)
+    if not default_only:
+        if local_settings_path is None:
+            local_settings_path = env.get(
+                'beanstalk_{0}_settings_path'.format(role),
+                os.path.join(
+                    os.getcwd(), BEANSTALK_LOCAL_BASE_PATH, 'beanstalk_{0}_settings.py'.format(role)
+                ))
+        if os.path.exists(local_settings_path):
+            setting_paths.append(local_settings_path)
 
     beanstalk_settings = SettingsDict(*setting_paths, **setting_patches)
 
-    env.beanstalk_settings = beanstalk_settings
+    env[env_key] = beanstalk_settings
     return beanstalk_settings
 
 
@@ -87,15 +89,15 @@ def run_hooked_actions(action_name):
 
     actions = beanstalk_settings[action_name]
     if len(actions) != 0:
-        print section_title('Run %s-%s %s' % tuple(action_name.lower().split('_')))
+        print section_title('Run {0}-{1} {2}'.format(*action_name.lower().split('_')))
         for action in actions:
             if isinstance(action, (list, tuple)):
-                action, args, kwargs = action
+                action, action_args, action_kwargs = action
             else:
-                args = []
-                kwargs = {}
+                action_args = []
+                action_kwargs = {}
             with hide('status'):
-                execute(action, *args, **kwargs)
+                execute(action, *action_args, **action_kwargs)
         return True
     else:
         return False
